
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v5.042.
use strict;
use warnings;

use Module::Build 0.28;
use lib qw{inc}; use AP::Build;

my %module_build_args = (
  "build_requires" => {
    "ExtUtils::CppGuess" => "0.11",
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Alien::Base" => "0.023",
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "find Google ProtoBuf library",
  "dist_author" => [
    "Mattia Barbon <mattia\@barbon.org>"
  ],
  "dist_name" => "Alien-ProtoBuf",
  "dist_version" => "0.02",
  "license" => "perl",
  "module_name" => "Alien::ProtoBuf",
  "recursive_test_files" => 1
);


my %fallback_build_requires = (
  "ExtUtils::CppGuess" => "0.11",
  "Module::Build" => "0.28"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = AP::Build->new(%module_build_args);


$build->create_build_script;
